@@ -341,7 +341,9 @@ class PeeweeDatabaseConnection(DatabaseConnection, PostgresqlDatabase):
 
         self._metadata = {}
 
-        PostgresqlDatabase.__init__(self, None)
+        autorollback = kwargs.pop('autorollback', True)
+
+        PostgresqlDatabase.__init__(self, None, autorollback=autorollback)
         DatabaseConnection.__init__(self, *args, **kwargs)
 
     @property
@@ -369,6 +371,7 @@ class PeeweeDatabaseConnection(DatabaseConnection, PostgresqlDatabase):
                 params['password'] = None
 
         PostgresqlDatabase.init(self, dbname, **params)
+        self._metadata = {}
 
         try:
             PostgresqlDatabase.connect(self)
